/*
 * Copyright 2007 Sun Microsystems, Inc.
 * All rights reserved.  You may not modify, use,
 * reproduce, or distribute this software except in
 * compliance with  the terms of the License at:
 * http://developer.sun.com/berkeley_license.html
 */


package cart.secure.client;

import cart.secure.ejb.BookException;


import java.util.Iterator;
import java.util.List;
import javax.ejb.EJB;
import cart.secure.ejb.Cart;
import javax.security.auth.login.LoginContext;

import javax.security.auth.callback.CallbackHandler;
import cart.secure.client.MyPresetCallbackHandler;
import javax.security.auth.login.LoginException;
import org.jboss.security.SimplePrincipal;
import org.jboss.security.auth.callback.SecurityAssociationHandler;


import org.jboss.security.client.SecurityClient; 

import org.jboss.security.client.SecurityClientFactory; 

import org.jboss.ejb3.annotation.SecurityDomain;






/**
 *
 * The client class for the CartBean example. Client adds books to the cart,
 * prints the contents of the cart, and then removes a book which hasn't been
 * added yet, causing a BookException.
 * @author ian
 */
public class CartClient {
    @EJB
    private static Cart cart;
    
    private static boolean loggedIn = false;
    private LoginContext loginContext = null;
    



    public CartClient(String[] args) {
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
    	CartClient client = new CartClient(args);
    	client.doLogin();
    	client.doTest();
    }
    
    
    
    
    
    
    
    
    
    
    public void doLogin(){
        try {
        	/*
            CallbackHandler handler = new MyPresetCallbackHandler("tam","CartUser");
            // jboss_jaas - name of a configuration in the jaas config file 
            loginContext = new LoginContext("jboss_jaas", handler);
            */
          
        	
        	SecurityAssociationHandler handler = new SecurityAssociationHandler();
        	SimplePrincipal user = new SimplePrincipal("tam");
        	handler.setSecurityInfo(user, "tam".toCharArray());
        	loginContext = new LoginContext("jboss_jaas",(CallbackHandler) handler);
            System.out.println("Created LoginContext");
            loginContext.login();
           
              
        	/*
        	   SecurityClient securityClient = SecurityClientFactory.getSecurityClient(); 

               securityClient.setSimple("tam", "tam"); 

               securityClient.login(); 
               */
               
            System.out.println("Logged in.");
            loggedIn = true;
    } catch (LoginException le) {
            System.out.println("Login failed");
            le.printStackTrace();
    }
        catch (Exception e) {
            System.out.println("Big Exception thrown");
            e.printStackTrace();
        }

        
        
     


        
        
        
        
        

    }
    public void doTest() {
        try {
        		if(loggedIn){
        				cart.initialize("sherman", "123");
        				cart.addBook("Infinite Jest");
        				cart.addBook("Bel Canto");
        				cart.addBook("Kafka on the Shore");

        				List<String> bookList = cart.getContents();

        				bookList = cart.getContents();

        				Iterator<String> iterator = bookList.iterator();

        				while (iterator.hasNext()) {
        					String title = (String) iterator.next();
        					System.out.println(title);
        				}

        				cart.removeBook("Gravity's Rainbow");
        				cart.remove();
        				doLogOut();
        				System.exit(0);
        		}
        } catch (BookException ex) {
            System.err.println("Caught a BookException: " + ex.getMessage());
            System.exit(1);
        } catch (Exception ex) {
            System.err.println("Caught an unexpected exception!");
            ex.printStackTrace();
            System.exit(1);
        }
    }
    
    public void doLogOut() {
    	 if (loggedIn && loginContext != null) {
             try {
                     loginContext.logout();
             } catch (LoginException e) {
                     System.out.println("Logout failed:" + e);
             }
    	 }

    	 System.out.println("## DONE! ##");

    	
    }
}








